@@ -1,5 +1,5 @@
 from fastapi import APIRouter, FastAPI
-from starlette.testclient import TestClient
+from fastapi.testclient import TestClient
 
 router = APIRouter()
 
